@@ -1,5 +1,4 @@
 import json
-import os
 from abc import ABC
 from typing import Any, Dict
 from urllib.parse import urlencode
@@ -94,30 +93,6 @@ class RequestWrapper(Transmission):
                 f"Issue requesting file, status: {res.status_code}, Reason: {res.reason} {res.text}"
             )
 
-    def send_file_old(
-        self, url_path: str, file_path: str, query_params: Dict = None, delete_file=False
-    ) -> Response:
-        with open(file_path, "rb") as f:
-            headers = self.headers
-            headers.update(
-                {
-                    "format": "multipart",
-                    "Content-Type": "multipart/json",
-                    "HTTP_CONTENT_DISPOSITION": "attachment; filename=",
-                }
-            )
-            request_path = f"{self._server_root}{url_path}"
-            res = requests.post(
-                request_path,
-                files={"file": f},
-                headers=headers,
-                cookies=self.cookies,
-                params=query_params,
-            )
-        if delete_file:
-            os.remove(file_path)
-        return res
-
     def patch(self, url_path: str, obj: Dict, query_params: Dict = None) -> Response:
         headers = self.headers
         headers.update(
